Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(274)

Unified Diff: pkg/analyzer/lib/task/dart.dart

Issue 1139473003: Removed CLASS_ELEMENTS from BuildCompilationUnitElementTask and cleaned up comments (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/analyzer/lib/src/task/dart.dart ('k') | pkg/analyzer/lib/task/general.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/analyzer/lib/task/dart.dart
diff --git a/pkg/analyzer/lib/task/dart.dart b/pkg/analyzer/lib/task/dart.dart
index 7356c97f9dc60f1756105d1bc4432186f69ccc88..c8325e1c6ffcf42fe1497ca5ff58f826a0b4d121 100644
--- a/pkg/analyzer/lib/task/dart.dart
+++ b/pkg/analyzer/lib/task/dart.dart
@@ -14,9 +14,8 @@ import 'package:analyzer/src/task/dart.dart';
import 'package:analyzer/task/model.dart';
/**
* The analysis errors associated with a target.
*
* The result is only available for targets representing a Dart compilation unit.
*/
final ListResultDescriptor<AnalysisError> DART_ERRORS =
new ListResultDescriptor<AnalysisError>(
@@ -28,7 +27,7 @@ final ListResultDescriptor<AnalysisError> DART_ERRORS =
* The list will be empty if there are no explicit imports, but will not be
* `null`.
*
* The result is only available for targets representing a Dart library.
*/
final ListResultDescriptor<Source> EXPLICITLY_IMPORTED_LIBRARIES =
new ListResultDescriptor<Source>(
@@ -40,7 +39,7 @@ final ListResultDescriptor<Source> EXPLICITLY_IMPORTED_LIBRARIES =
* The list will be empty if there are no exported libraries, but will not be
* `null`.
*
* The result is only available for targets representing a Dart library.
*/
final ListResultDescriptor<Source> EXPORTED_LIBRARIES =
new ListResultDescriptor<Source>('EXPORTED_LIBRARIES', Source.EMPTY_LIST);
@@ -52,7 +51,7 @@ final ListResultDescriptor<Source> EXPORTED_LIBRARIES =
* The list will minimally contain the source for `dart:core` because it is
* implicitly imported into every library, and therefore will never be `null`.
*
* The result is only available for targets representing a Dart library.
*/
final ListResultDescriptor<Source> IMPORTED_LIBRARIES =
new ListResultDescriptor<Source>('IMPORTED_LIBRARIES', Source.EMPTY_LIST);
@@ -63,7 +62,7 @@ final ListResultDescriptor<Source> IMPORTED_LIBRARIES =
* The list will be empty if there are no parts, but will not be `null`. The
* list does *not* include the source for the defining compilation unit.
*
* The result is only available for targets representing a Dart library.
*/
final ListResultDescriptor<Source> INCLUDED_PARTS =
new ListResultDescriptor<Source>('INCLUDED_PARTS', Source.EMPTY_LIST);
@@ -72,7 +71,7 @@ final ListResultDescriptor<Source> INCLUDED_PARTS =
* A flag specifying whether a library is dependent on code that is only
* available in a client.
*
* The result is only available for targets representing a Dart library.
*/
final ResultDescriptor<bool> IS_CLIENT =
new ResultDescriptor<bool>('IS_CLIENT', false);
@@ -80,7 +79,7 @@ final ResultDescriptor<bool> IS_CLIENT =
/**
* A flag specifying whether a library is launchable.
*
* The result is only available for targets representing a Dart library.
*/
final ResultDescriptor<bool> IS_LAUNCHABLE =
new ResultDescriptor<bool>('IS_LAUNCHABLE', false);
@@ -88,7 +87,7 @@ final ResultDescriptor<bool> IS_LAUNCHABLE =
/**
* The fully built [LibraryElement] associated with a library.
*
* The result is only available for targets representing a Dart library.
*/
final ResultDescriptor<LibraryElement> LIBRARY_ELEMENT =
new ResultDescriptor<LibraryElement>('LIBRARY_ELEMENT', null);
@@ -98,28 +97,34 @@ final ResultDescriptor<LibraryElement> LIBRARY_ELEMENT =
*
* The AST structure will not have resolution information associated with it.
*
* The result is only available for targets representing a Dart compilation unit.
*/
final ResultDescriptor<CompilationUnit> PARSED_UNIT =
new ResultDescriptor<CompilationUnit>('PARSED_UNIT', null,
cachingPolicy: AST_CACHING_POLICY);
/**
- * The resolved [CompilationUnit] associated with a unit.
+ * The resolved [CompilationUnit] associated with a compilation unit.
*
- * The result is only available for targets representing a unit.
+ * The result is only available for [LibrarySpecificUnit]s.
*/
final ResultDescriptor<CompilationUnit> RESOLVED_UNIT =
new ResultDescriptor<CompilationUnit>('RESOLVED_UNIT', null,
cachingPolicy: AST_CACHING_POLICY);
/**
+ * The kind of a [Source].
+ */
+final ResultDescriptor<SourceKind> SOURCE_KIND =
+ new ResultDescriptor<SourceKind>('SOURCE_KIND', SourceKind.UNKNOWN);
+
+/**
* The token stream produced while scanning a compilation unit.
*
* The value is the first token in the file, or the special end-of-file marker
* at the end of the stream if the file does not contain any tokens.
*
* The result is only available for targets representing a Dart compilation unit.
*/
final ResultDescriptor<Token> TOKEN_STREAM = new ResultDescriptor<Token>(
'TOKEN_STREAM', null, cachingPolicy: TOKEN_STREAM_CACHING_POLICY);
@@ -130,7 +135,7 @@ final ResultDescriptor<Token> TOKEN_STREAM = new ResultDescriptor<Token>(
* The list will include the source of the defining unit and [INCLUDED_PARTS].
* So, it is never empty or `null`.
*
* The result is only available for targets representing a Dart library.
*/
final ListResultDescriptor<Source> UNITS =
new ListResultDescriptor<Source>('UNITS', Source.EMPTY_LIST);
@@ -14,9 +14,8 @@ import 'package:analyzer/src/task/dart.dart';
import 'package:analyzer/task/model.dart';
/**
- * The analysis errors associated with a target.
- *
- * The result is only available for targets representing a Dart compilation unit.
+ * The analysis errors associated with a [Source] representing a compilation
+ * unit.
*/
final ListResultDescriptor<AnalysisError> DART_ERRORS =
@@ -28,7 +27,7 @@ final ListResultDescriptor<AnalysisError> DART_ERRORS =
* `null`.
*
- * The result is only available for targets representing a Dart library.
+ * The result is only available for [Source]s representing a library.
*/
final ListResultDescriptor<Source> EXPLICITLY_IMPORTED_LIBRARIES =
@@ -40,7 +39,7 @@ final ListResultDescriptor<Source> EXPLICITLY_IMPORTED_LIBRARIES =
* `null`.
*
- * The result is only available for targets representing a Dart library.
+ * The result is only available for [Source]s representing a library.
*/
final ListResultDescriptor<Source> EXPORTED_LIBRARIES =
@@ -52,7 +51,7 @@ final ListResultDescriptor<Source> EXPORTED_LIBRARIES =
* implicitly imported into every library, and therefore will never be `null`.
*
- * The result is only available for targets representing a Dart library.
+ * The result is only available for [Source]s representing a library.
*/
final ListResultDescriptor<Source> IMPORTED_LIBRARIES =
@@ -63,7 +62,7 @@ final ListResultDescriptor<Source> IMPORTED_LIBRARIES =
* list does *not* include the source for the defining compilation unit.
*
- * The result is only available for targets representing a Dart library.
+ * The result is only available for [Source]s representing a library.
*/
final ListResultDescriptor<Source> INCLUDED_PARTS =
@@ -72,7 +71,7 @@ final ListResultDescriptor<Source> INCLUDED_PARTS =
* available in a client.
*
- * The result is only available for targets representing a Dart library.
+ * The result is only available for [Source]s representing a library.
*/
final ResultDescriptor<bool> IS_CLIENT =
@@ -80,7 +79,7 @@ final ResultDescriptor<bool> IS_CLIENT =
* A flag specifying whether a library is launchable.
*
- * The result is only available for targets representing a Dart library.
+ * The result is only available for [Source]s representing a library.
*/
final ResultDescriptor<bool> IS_LAUNCHABLE =
@@ -88,7 +87,7 @@ final ResultDescriptor<bool> IS_LAUNCHABLE =
* The fully built [LibraryElement] associated with a library.
*
- * The result is only available for targets representing a Dart library.
+ * The result is only available for [Source]s representing a library.
*/
final ResultDescriptor<LibraryElement> LIBRARY_ELEMENT =
@@ -98,28 +97,34 @@ final ResultDescriptor<LibraryElement> LIBRARY_ELEMENT =
* The AST structure will not have resolution information associated with it.
*
- * The result is only available for targets representing a Dart compilation unit.
+ * The result is only available for [Source]s representing a compilation unit.
*/
final ResultDescriptor<CompilationUnit> PARSED_UNIT =
@@ -98,28 +97,34 @@ final ResultDescriptor<LibraryElement> LIBRARY_ELEMENT =
* at the end of the stream if the file does not contain any tokens.
*
- * The result is only available for targets representing a Dart compilation unit.
+ * The result is only available for [Source]s representing a compilation unit.
*/
final ResultDescriptor<Token> TOKEN_STREAM = new ResultDescriptor<Token>(
@@ -130,7 +135,7 @@ final ResultDescriptor<Token> TOKEN_STREAM = new ResultDescriptor<Token>(
* So, it is never empty or `null`.
*
- * The result is only available for targets representing a Dart library.
+ * The result is only available for [Source]s representing a library.
*/
final ListResultDescriptor<Source> UNITS =
« no previous file with comments | « pkg/analyzer/lib/src/task/dart.dart ('k') | pkg/analyzer/lib/task/general.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698